# crawlMp-gui

![GitHub](https://img.shields.io/github/license/domarm-comat/crawlMpGui)

Graphical interface for crawlMp.  
Results are paged into page_sized chunks.  
User can sort hits by column and apply multiple filter based on column type.  

# Icons attribution

Icon made by [Roundicons](https://www.flaticon.com/authors/roundicons "Roundicons") from [www.flaticon.com](www.flaticon.com)  
Icon made by [Smauj](https://www.flaticon.com/authors/Smauj "Smauj") from [www.flaticon.com](www.flaticon.com)  
Icon made by [deemakdaksina](https://www.flaticon.com/authors/deemakdaksina "deemakdaksina") from [www.flaticon.com](www.flaticon.com)  